<?php

/**
 * @file
 * Admin interface for general ldap data definition
 *
 */
/*
 * Implements hook_form
 */
function ldap_data_admin_form($form, &$form_state, $op = NULL, $ldap_data = NULL) {
  $form['#title'] = "Configure LDAP Query";
  $form['data']   = array(
    '#type'  => 'fieldset',
    '#title' => t('LDAP Search'),
  );

  $form['data']['did'] = array(
    '#type' => 'textfield',
    '#title' => t('Machine name for this search'),
    '#description' => t('May only contain alphanumeric characters (a-z, A-Z, 0-9, and _)'),
    '#size' => '30',
    '#maxlength' => '20',
    '#required' => TRUE,
    '#disabled' => $op == 'edit',
    '#default_value' => isset($ldap_data) ? $ldap_data->did : '',
  );

  $form['data']['name'] = array(
    '#type' => 'textfield',
    '#title' => t('Name'),
    '#description' => t('Choose a <strong>unique</strong> name for this server configuration'),
    '#size' => '80',
    '#maxlength' => '255',
    '#default_value' => isset($ldap_data) ? $ldap_data->name : '',
    '#required' => TRUE,
  );

  $form['data']['description'] = array(
    '#type' => 'textarea',
    '#title' => t('Description'),
    '#default_value' => isset($ldap_data) ? $ldap_data->description : '',
  );

  require_once(drupal_get_path('module', 'ldap_servers') . '/ldap_servers.module');
  $ldap_servers = ldap_servers_get_servers(NULL, 'all');
  foreach ($ldap_servers as $name => $ldap_server) {
      $options[$ldap_server->sid] = $ldap_server->name;
  }
//kpr($ldap_servers);
  $form['data']['sid'] = array(
    '#type' => 'select',
    '#title' => t('LDAP Server'),
    '#options' => $options,
    '#default_value' => isset($ldap_data) ? $ldap_data->sid : '',
    '#required' => TRUE,
  );
  $form['data']['basedn'] = array(
    '#type' => 'textfield',
    '#title' => t('Search Base'),
    '#description' => t('Starting point for the search'),
    '#size' => '100',
    '#maxlength' => '255',
    '#default_value' => isset($ldap_data) ? $ldap_data->basedn : '',
    '#required' => TRUE,
  );

  $form['data']['filter'] = array(
    '#type' => 'textarea',
    '#title' => t('LDAP Filter'),
    '#description' => t('The filter should conform to the string representation for search filters as defined in RFC 4515. If not provided, the default filter, (objectClass=*), is used.'),
    '#default_value' => isset($ldap_data) ? $ldap_data->filter : '',
  );

  $form['data']['attributes'] = array(
    '#type' => 'textarea',
    '#title' => t('LDAP Attributes'),
    '#description' => t('If the search finds one or more  entries, the attributes specified by this field are returned. If * or no attributes are listed, all user attributes are returned.'),
    '#default_value' => isset($ldap_data) ? implode("\n", $ldap_data->attributes) : '',
    '#required' => TRUE,
  );

  $form['data']['scope'] = array(
    '#type' => 'select',
    '#title' => t('LDAP Search scope'),
    '#description' => t('Select the scope of the search'),
    '#options' => array('LDAP_SCOPE_BASE' => t('Base'), 'LDAP_SCOPE_ONELEVEL' => t('One'), 'LDAP_SCOPE_SUBTREE' => t('Subtree')),
    '#default_value' => isset($ldap_data) ? $ldap_data->scope : '',
    '#required' => TRUE,
  );

  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save configuration'),
  );

  $action = ($op == 'add') ? 'Add' : 'Update';
  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => $action,
    '#weight' => 100,
  );

  return $form;
}

/**
 * Submit hook for the LDAP Search form
 * Implements hook_submit
 */
function ldap_data_admin_form_submit($form, &$form_state) {
//kpr(array('ok')); die();
  $ldap_data_submission = (object) $form_state['values'];
  field_attach_submit('ldap_data', $ldap_data_submission, $form, $form_state);
  // Pass $ldap_data_submission->attributes to an array triming each line
  $attributes = explode("\n", $ldap_data_submission->attributes);
  $ldap_data_submission->attributes = array();
  foreach ($attributes as $attribute) {
    $attr = trim($attribute);
    if (! empty($attr)) {
      $ldap_data_submission->attributes[] = strtolower($attr);
    }
  }
  // $ldap_data_submission->filter: default value = (objectClass=*)
  if (trim($ldap_data_submission->filter) == '' || trim($ldap_data_submission->filter) == '*') {
    $ldap_data_submission->filter = '(objectClass=*)';
  }
  $ldap_data = ldap_data_save($ldap_data_submission);
  $uri = entity_uri('ldap_data', $ldap_data);
  $form_state['redirect'] = $uri['path'];
}


/**
* Delete a ldap data search
*/
function ldap_data_delete_form_submit($form, &$form_state) {
  $ldap_data_submission = (object) $form_state['values'];
  ldap_data_delete($ldap_data_submission->did);
  $form_state['redirect'] = LDAP_DATA_MENU_BASE_PATH . '/list';
}

/**
* Delete a ldap data search (confirmation form)
*/
function ldap_data_delete_form($form, &$form_state, $ldap_data) {
//kpr($ldap_data); //die();
    $variables = array(
      'ldap_data' => $ldap_data, 'actions' => FALSE, 'type' => 'detail'
    );
    $form['data']['#markup'] = '<div>' . theme('ldap_data_search', $variables) . '</div>';
//    $form['#action'] = url(LDAP_DATA_MENU_BASE_PATH . '/' . $ldap_data->did . '/delete');  // -------------> ALDATU!!!!

    $form['data']['did'] = array(
      '#type' => 'hidden',
      '#value' => $ldap_data->did,
    );

    return confirm_form(
      $form,
      'Delete Confirmation Form',
      LDAP_DATA_MENU_BASE_PATH . '/ldap_data/list',
        '<p>' . t('Are you sure you want to delete the LDAP search named <em><strong>%name</strong></em> ?', array('%name' => $ldap_data->name)) . '</p><p>' .
        t('This action cannot be undone.') . '</p>',
      t('Delete'),
      t('Cancel')
    );
}

/**
* List all ldap data searches
*/
function ldap_data_list() {
  $ldap_data = ldap_data_load_multiple();
  $rows      = array();
  foreach ($ldap_data as $data) {
    $rows[] = array($data->name,
                    $data->basedn,
                    ' | ' .
                    l(t('edit'),   'admin/structure/ldap_data/' . $data->did . '/edit') . ' | ' .
                    //l(t('test'),   'admin/structure/ldap_data/' . $data->did . '/test') . ' | ' .
                    l(t('delete'), 'admin/structure/ldap_data/' . $data->did . '/delete') . ' | '
              );
  }
  $output = array(
    '#theme' => 'table',
    '#header' => array(t('Name'), t('Base DN'), t('Actions')), // Table Headers
    '#rows' => $rows,
  );
  return $output;
}

